@@ -9,7 +9,7 @@ from pca.pca import (
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '1.5.1'
+__version__ = '1.8.2'
 
 # module level doc-string
 __doc__ = """
@@ -34,8 +34,14 @@ Examples
 >>>
 >>> # Make plots
 >>> fig, ax = model.scatter()
+>>>
+>>> # Scree plot together with explained variance.
 >>> fig, ax = model.plot()
+>>>
+>>> # Plot loadings.
 >>> fig, ax = model.biplot()
+>>>
+>>> # Plot loadings with outliers
 >>> fig, ax = model.biplot(SPE=True, hotellingt2=True)
 >>>
 >>> 3D plots
